@@ -3,7 +3,6 @@ import base64
 from bs4 import BeautifulSoup
 from Crypto.Cipher import AES
 from urllib.request import urlopen, Request
-from .version import VERSION
 
 
 def read_bash_return(cmd, single=True):
@@ -18,14 +17,14 @@ def read_bash_return(cmd, single=True):
 
 def docker_check():
     f = None
-    user_home = read_bash_return("echo $HOME")
-    try:
-        f = open(os.path.join(user_home, ".bashrc"), "r")
-    except IOError:
-        try:
-            f = open(os.path.join(user_home, ".bash_profile"), "r")
-        except IOError:
-            print("Bash profile file does not exist.")
+    user_home = os.environ.get('HOME')
+    for rcfile in ['.bashrc', '.bash_profile', '.zshrc', '.zprofile']:
+        rcpath = os.path.join(user_home, rcfile)
+        if os.path.exists(rcpath):
+            f = open(os.path.join(user_home, rcpath), "r")
+            break
+    if not f:
+        raise Exception("No sehll rc or profile files exist.")
     bash_profile = f.read()
     try:
         docker_flag = bash_profile.split('DOCKER_FLAG="')[1][0]
@@ -86,14 +85,14 @@ def domain_from_email(address):
 class BashProfile:
     def __init__(self):
         f = None
-        user_home = read_bash_return("echo $HOME")
-        try:
-            f = open(os.path.join(user_home, ".bashrc"), "r")
-        except IOError:
-            try:
-                f = open(os.path.join(user_home, ".bash_profile"), "r")
-            except IOError:
-                print("Bash profile file does not exist.")
+        user_home = os.environ.get('HOME')
+        for rcfile in ['.bashrc', '.bash_profile', '.zshrc', '.zprofile']:
+            rcpath = os.path.join(user_home, rcfile)
+            if os.path.exists(rcpath):
+                f = open(os.path.join(user_home, rcpath), "r")
+                break
+        if not f:
+            raise Exception("No shell rc or profile files exist.")
         self.other_profile_flag = False
         if docker_check():
             f2 = None
@@ -175,10 +174,19 @@ class Encryption:
 
 
 def bump_version():
-    all_version = VERSION.split(".")
-    new_all_version = VERSION.split(".")[:-1]
+    """
+    Only run in the project root directory, this is for travis to bump the version file only!
+
+    :return:
+    """
+    __root__ = os.path.abspath("")
+    with open(os.path.join(__root__, 'VERSION')) as version_file:
+        version = version_file.read().strip()
+
+    all_version = version.replace('"', "").split(".")
+    new_all_version = version.split(".")[:-1]
     new_all_version.append(str(int(all_version[-1]) + 1))
-    new_line = "VERSION = "+ '"{}"'.format(".".join(new_all_version)) + "\n"
-    with open("onepassword/version.py", "w") as fp:
+    new_line = '.'.join(new_all_version) + "\n"
+    with open("{}/VERSION".format(__root__), "w") as fp:
         fp.write(new_line)
-    fp.close()
\ No newline at end of file
+    fp.close()
